@@ -476,7 +476,7 @@ class TaskGroup(abc.TaskGroup):
             raise RuntimeError('This task group is not active; no new tasks can be spawned.')
 
         name = name or get_callable_name(func)
-        if _native_task_names is None:
+        if _native_task_names:
             task = create_task(self._run_wrapped_task(func, args), name=name)  # type: ignore
         else:
             task = create_task(self._run_wrapped_task(func, args))
@@ -690,7 +690,7 @@ class StreamProtocol(asyncio.Protocol):
 
     def eof_received(self) -> Optional[bool]:
         self.read_event.set()
-        return None
+        return True
 
     def pause_writing(self) -> None:
         self.write_future = asyncio.Future()
@@ -745,8 +745,7 @@ class SocketStream(abc.SocketStream):
     async def receive(self, max_bytes: int = 65536) -> bytes:
         with self._receive_guard:
             await checkpoint()
-            if not self._protocol.read_queue and not self._transport.is_closing():
-                self._protocol.read_event.clear()
+            if not self._protocol.read_event.is_set() and not self._transport.is_closing():
                 self._transport.resume_reading()
                 await self._protocol.read_event.wait()
                 self._transport.pause_reading()
@@ -766,6 +765,11 @@ class SocketStream(abc.SocketStream):
                 chunk, leftover = chunk[:max_bytes], chunk[max_bytes:]
                 self._protocol.read_queue.appendleft(leftover)
 
+            # If the read queue is empty, clear the flag so that the next call will block until
+            # data is available
+            if not self._protocol.read_queue:
+                self._protocol.read_event.clear()
+
         return chunk
 
     async def send(self, item: bytes) -> None:
@@ -1228,6 +1232,7 @@ async def open_signal_receiver(*signals: int):
     queue = asyncio.Queue()  # type: asyncio.Queue[int]
     handled_signals = set()
     agen = process_signal_queue()
+    await checkpoint()
     try:
         for sig in set(signals):
             loop.add_signal_handler(sig, queue.put_nowait, sig)
